Changelog
=========

1.6.0
-----

* remove unnecessary parameters in order to support pdt 1.1+ (bubenkoff)

1.5.1
-----

* `case-data get-revisions` moved to `case-data get-not-deployed` (bubenkoff)

1.4.3
-----

* Added revision to deploy command (bubenkoff)
* Make `--case` for deploy command optional (bubenkoff)

1.4.2
-----

* Added case-data command and it's get-revisions subcommand to get case revisions (bubenkoff)

1.3.1
-----

* Fixed graph command (hvdklauw)

1.3.0
-----

* Added graph command for graphing the migration dependency tree (hvdklauw)

1.2.4
-----

* Initial public release (bubenkoff)
